@@ -3,8 +3,7 @@
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
-#ifndef MOCK_BUTTON_H
-#define MOCK_BUTTON_H
+#pragma once
 
 #include "../src/decorationbutton.h"
 
@@ -12,8 +11,6 @@ class MockButton : public KDecoration2::DecorationButton
 {
     Q_OBJECT
 public:
-    MockButton(KDecoration2::DecorationButtonType type, const QPointer<KDecoration2::Decoration> &decoration, QObject *parent = nullptr);
+    MockButton(KDecoration2::DecorationButtonType type, KDecoration2::Decoration *decoration, QObject *parent = nullptr);
     void paint(QPainter *painter, const QRect &repaintRegion) override;
 };
-
-#endif
