@@ -3,15 +3,13 @@
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
  */
-#ifndef KDECORATION2_DECORATION_H
-#define KDECORATION2_DECORATION_H
+#pragma once
 
 #include "decorationshadow.h"
 #include <kdecoration2/kdecoration2_export.h>
 
 #include <QMargins>
 #include <QObject>
-#include <QPointer>
 #include <QRect>
 
 class QHoverEvent;
@@ -87,16 +85,16 @@ class KDECORATIONS2_EXPORT Decoration : public QObject
      * Decoration should set this property to @c true.
      **/
     Q_PROPERTY(bool opaque READ isOpaque NOTIFY opaqueChanged)
+
+    Q_PROPERTY(QString decorationName READ decorationName);
+
 public:
     ~Decoration() override;
 
     /**
      * The DecoratedClient for this Decoration.
-     * As long as the Decoration is alive it is guaranteed that the object is not
-     * deleted. Thus it is save to access using QWeakPointer::data in e.g. a sublcass
-     * of Decoration without promoting to QSharedPointer.
      **/
-    QWeakPointer<DecoratedClient> client() const;
+    DecoratedClient *client() const;
 
     QMargins borders() const;
     int borderLeft() const;
@@ -111,13 +109,15 @@ public:
     Qt::WindowFrameSection sectionUnderMouse() const;
     QRect titleBar() const;
     bool isOpaque() const;
+    QString decorationName() const;
+    void setDecorationName(QString name);
 
     /**
      * DecorationShadow for this Decoration. It is recommended that multiple Decorations share
      * the same DecorationShadow. E.g one DecorationShadow for all inactive Decorations and one
      * for the active Decoration.
      **/
-    QSharedPointer<DecorationShadow> shadow() const;
+    std::shared_ptr<DecorationShadow> shadow() const;
 
     /**
      * The decoration's geometry in local coordinates.
@@ -137,11 +137,11 @@ public:
      * init is invoked.
      * @internal
      **/
-    void setSettings(const QSharedPointer<DecorationSettings> &settings);
+    void setSettings(const std::shared_ptr<DecorationSettings> &settings);
     /**
      * @returns The DecorationSettings used for this Decoration.
      **/
-    QSharedPointer<DecorationSettings> settings() const;
+    std::shared_ptr<DecorationSettings> settings() const;
 
     /**
      * Implement this method in inheriting classes to provide the rendering.
@@ -194,8 +194,11 @@ public Q_SLOTS:
      *
      * An inheriting class should override this method and perform all initialization in
      * this method instead of the constructor.
+     *
+     * @return true if initialization has been successful,
+     * false otherwise (for example, a QML component could not be loaded)
      **/
-    virtual void init();
+    virtual bool init() = 0;
 
 Q_SIGNALS:
     void blurRegionChanged();
@@ -204,7 +207,7 @@ Q_SIGNALS:
     void sectionUnderMouseChanged(Qt::WindowFrameSection);
     void titleBarChanged();
     void opaqueChanged(bool);
-    void shadowChanged(const QSharedPointer<DecorationShadow> &shadow);
+    void shadowChanged(const std::shared_ptr<DecorationShadow> &shadow);
     void damaged(const QRegion &region);
 
 protected:
@@ -229,7 +232,7 @@ protected:
      **/
     void setTitleBar(const QRect &rect);
     void setOpaque(bool opaque);
-    void setShadow(const QSharedPointer<DecorationShadow> &shadow);
+    void setShadow(const std::shared_ptr<DecorationShadow> &shadow);
 
     virtual void hoverEnterEvent(QHoverEvent *event);
     virtual void hoverLeaveEvent(QHoverEvent *event);
@@ -242,11 +245,9 @@ protected:
 private:
     friend class DecorationButton;
     class Private;
-    QScopedPointer<Private> d;
+    std::unique_ptr<Private> d;
 };
 
 } // namespace
 
 Q_DECLARE_METATYPE(KDecoration2::Decoration *)
-
-#endif
